@@ -1,4 +1,4 @@
-# Copyright 2009-2013 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2014 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -16,8 +16,7 @@
 
 """Tests for the bzrsupport module."""
 
-from __future__ import unicode_literals
-from __future__ import print_function
+from __future__ import print_function, unicode_literals, absolute_import, division
 
 import os
 import os.path
@@ -33,7 +32,7 @@ class BzrFixture(Fixture):
     def new_bzr_directory(self, initialised=True):
         bzr_directory = temp_dir()
         if initialised:
-            with file(os.devnull, 'w') as DEVNULL:
+            with open(os.devnull, 'w') as DEVNULL:
                 Executable('bzr').check_call(['init'], cwd=bzr_directory.name, stdout=DEVNULL, stderr=DEVNULL)
         return bzr_directory
 
@@ -54,7 +53,7 @@ class BzrTests(object):
         bzr = Bzr(fixture.bzr_directory.name)
         vassert( bzr.is_checked_in() )
 
-        file(os.path.join(fixture.bzr_directory.name, 'afile'), 'w').close()
+        open(os.path.join(fixture.bzr_directory.name, 'afile'), 'w').close()
         vassert( not bzr.is_checked_in() )
         
     @test(BzrFixture)
